+++
title = "Exploring the pareto fronts of actuation technologies for high performance mechatronic systems"
draft = true
+++

Tags
:


Reference
: (<a href="#citeproc_bib_item_1">Csencsics and Schitter 2020</a>)

Author(s)
: Csencsics, E., &amp; Schitter, G.

Year
: 2020


## Abstract {#abstract}

> This paper proposes a novel method for estimating the limitations of individual actuation technologies for a desired system class based on analytically obtained relations, which can be used to systematically trade off desired range and speed specifications in the design phase.
> The method is presented along the example of **fast steering mirrors** with the tradeoff limit curves estimated for the established **piezoelectric**, **lorentz force** and **hybrid reluctance** actuation technologies.

<a id="figure--fig:csencsics20-fsm-schematic"></a>

{{< figure src="/ox-hugo/csencsics20_fsm_schematic.png" caption="<span class=\"figure-number\">Figure 1: </span>Fast Steering Mirror system. The main components are: mirror, actuators, position sensors and suspension system." >}}


## Fast Steering Mirrors {#fast-steering-mirrors}


### Application area and performance specification {#application-area-and-performance-specification}

<a id="table--tab:fsm-requirements"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:fsm-requirements">Table 1</a>:</span>
  FSM performance requirements for two application
</div>

| Application       | Pointing        | Scanning |
|-------------------|-----------------|----------|
| System Range      | large           | large    |
| System Dimensions | arbitrary       | compact  |
| Main objective    | dist. rejection | tracking |
| Bandwidth         | high            | high     |
| Motion amplitude  | small           | large    |
| Mover inertia     | arbitrary       | small    |
| Precision         | high            | high     |


### Safe operating area {#safe-operating-area}

The concept of the Safe Operating Area (SOA) relates the frequency of a sinusoidal reference to the maximum admissible scan amplitude that still stays within the limits of the system.

From figure [2](#figure--fig:csencsics20-soa) we can already see that piezo are typically used for system with high bandwidth and small range.

<a id="figure--fig:csencsics20-soa"></a>

{{< figure src="/ox-hugo/csencsics20_soa.png" caption="<span class=\"figure-number\">Figure 1: </span>Measured safe operating area of closed-loop FSM systems with sinusoidal reference signals. Piezo actuated in blue, lorentz force actuated in red and hybrid reluctance actuated in green." >}}


## Limitations of actuator technology {#limitations-of-actuator-technology}


### Piezo actuation {#piezo-actuation}

Piezo actuated FMS are in general **high stiffness** system, for which the **bandwidth limitation** for feedback control is typically given by the **first mechanical resonance**.

<a id="figure--fig:csencsics20-typical-piezo-fsm"></a>

{{< figure src="/ox-hugo/csencsics20_typical_piezo_fsm.png" caption="<span class=\"figure-number\">Figure 1: </span>Piezo actuated FSM cross section" >}}

The angular range of the FSM is:

\begin{equation}
\phi = \frac{L/1000}{2 d}
\end{equation}

with \\(L\\) the length of the stack, and d the distance between the stacks and the center of rotation (the factor 1000 is linked to the fact that typical piezo stack have a store equal to 0.1% of their length).

The first resonance frequency is:

\begin{equation}
f\_{PZA} = \frac{1}{2\pi L}\sqrt{\frac{3E}{\rho\_\text{piezo}}}
\end{equation}

with \\(E\\) the elastic modulus and \\(\rho\_\text{piezo}\\) the density of the piezo material.

As the resonance limits the achievable bandwidth, we therefore have that \\(f\_{\text{max,PZA}} \propto 1/\phi\\).


### Lorentz force actuation {#lorentz-force-actuation}

Lorentz force actuated FSM are in general **low stiffness** systems, which typically have a control bandwidth beyond the suspension mode that is usually limited by the **internal modes of the moving part**.

The mover's mass is dominating the dynamics of low stiffness systems beyond the suspension mode.

<a id="figure--fig:csencsics20-typical-lorentz-fsm"></a>

{{< figure src="/ox-hugo/csencsics20_typical_lorentz_fsm.png" caption="<span class=\"figure-number\">Figure 1: </span>Lorentz force actuator designs." >}}

\begin{equation}
f\_\text{max,LFA} = \frac{1}{2\pi} k\_\text{LFA} \sqrt{\frac{1}{\phi J\_\text{init} + \Delta\_J + 2 d \phi^2}}
\end{equation}


### Hybrid reluctance force actuation {#hybrid-reluctance-force-actuation}

<a id="figure--fig:csencsics20-typical-hybrid-reluctance-fsm"></a>

{{< figure src="/ox-hugo/csencsics20_typical_hybrid_reluctance_fsm.png" caption="<span class=\"figure-number\">Figure 1: </span>Hybrid reluctance actuator designs" >}}


## Pareto front estimates for FSM systems {#pareto-front-estimates-for-fsm-systems}

<a id="figure--fig:csencsics20-pareto-estimate"></a>

{{< figure src="/ox-hugo/csencsics20_pareto_estimate.png" caption="<span class=\"figure-number\">Figure 1: </span>Two dimensional performance space for FSM systems showing the tradeoff between range and bandwidth. Commercially available (symbols) as well as academically reported systems (dots) actuated by piezo (blue), Lorentz force (red) and reluctance actuators (green) are depicted." >}}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Csencsics, Ernst, and Georg Schitter. 2020. “Exploring the Pareto Fronts of Actuation Technologies for High Performance Mechatronic Systems.” <i>IEEE/ASME Transactions on Mechatronics</i>. IEEE.</div>
</div>
