+++
title = "Advanced motion control for precision mechatronics: control, identification, and learning of complex systems"
author = ["Dehaeze Thomas"]
draft = false
+++

Tags
: [Motion Control]({{< relref "motion_control.md" >}})

Reference
: (<a href="#citeproc_bib_item_1">Oomen 2018</a>)

Author(s)
: Oomen, T.

Year
: 2018


## Introduction {#introduction}

Control of positioning systems is traditionally simplified by an excellent mechanical design.
In particular, the mechanical design is such that the system is stiff and highly reproducible.
In conjunction with moderate performance requirements, the control bandwidth is well-below the resonance frequency of the flexible mechanics as is shown in [Figure 1](#figure--fig:oomen18-next-gen-loop-gain) (a).
As a result, the system can often be completely **decoupled** in the frequency range relevant for control.
Consequently, the control design is divided into well-manageable SISO control loops.

Although motion control design is well developed, presently available techniques mainly apply to positioning systems that behave as a rigid body in the relevant frequency range.
On one hand, increasing performance requirements hamper the validity of this assumption, since the bandwidth has to increase, leading to flexible dynamics in the cross-over region, see [Figure 1](#figure--fig:oomen18-next-gen-loop-gain) (b).

<a id="figure--fig:oomen18-next-gen-loop-gain"></a>

{{< figure src="/ox-hugo/oomen18_next_gen_loop_gain.png" caption="<span class=\"figure-number\">Figure 1: </span>Envisaged developments in motion systems. In traditional motion systems, the control bandwidth takes place in the rigid-body region. In the next generation systemes, flexible dynamics are foreseen to occur within the control bandwidth." >}}


## Traditional motion control {#traditional-motion-control}

In the frequency range that is relevant for control, the dynamical behavior is mainly determined by the mechanics.
In particular, the mechanics can typically be described as:

\begin{equation}
G\_m = \sum\_{i=1}^{n\_{RB}} \frac{c\_i b\_i^T}{s^2} + \sum\_{n\_{RB} + 1}^{n\_s} \frac{c\_i b\_i^T}{s^2 + 2\xi \omega\_i s + \omega\_i^2}
\end{equation}

where the first term refers to rigid body modes and the second term to flexible modes.

-   \\(n\_{RB}\\) is the number of rigid body modes
-   \\(c\_i \in \mathbb{R}^{n\_y}\\) and \\(b\_i \in \mathbb{R}^{n\_u}\\) are associated with the mode shapes
-   \\(\xi\_i, \omega\_i \in \mathbb{R}\_+\\)

In traditional positioning systems, the number of actuators \\(n\_u\\) and sensors \\(n\_y\\) equals the number of rigid body modes \\(n\_{RB}\\) and are positioned such that the matrix \\(\sum\_{i=1}^{n\_{RB}} c\_i b\_i^T\\) is invertible.
In this case, matrices \\(T\_u\\) and \\(T\_y\\) can be selected such that:

\begin{equation}
G = T\_y G\_m T\_u = \frac{1}{s^2} I\_{n\_{RB}} + G\_{\text{flex}}
\end{equation}

A tradition motion control architecture is shown in [Figure 2](#figure--fig:oomen18-control-architecture).

<a id="figure--fig:oomen18-control-architecture"></a>

{{< figure src="/ox-hugo/oomen18_control_architecture.png" caption="<span class=\"figure-number\">Figure 2: </span>Traditional motion control architecture" >}}


### Traditional feedforward design {#traditional-feedforward-design}

[Feedforward Control]({{< relref "feedforward_control.md" >}}) can effectively compensate for reference induced error signals.
In particular, \\(f\\) should be selected such that \\(r - G f\\) is minimized.
In the low frequency range, the system is decoupled and \\(G\_{\text{flex}}\\) can be ignored, in which case \\(f = G^{-1} r\\).
In practice, the feedforward signal is selected as \\(f = ms^2 r\\).


### Traditional feedback design {#traditional-feedback-design}

The [Feedback Controller]({{< relref "feedback_control.md" >}}) has to minimize \\((1 + GK)^{-1}(\delta - v)\\).
The main idea is that rigid body decoupling of \\(G\\) enables the shaping of the diagonal elements of \\(K\\) through a decentralized feedback controller.
As a result, each diagonal element of \\(K\\) may be tuned independently.
Typically, a PID controller is tuned through manual loop-shaping, followed by notch filters to account the the flexible modes that hamper stability and/or performance.


### Traditional design procedure {#traditional-design-procedure}

Traditional motion control design divides the multi-variable control design problems into sub-problems that are manageable by manual control design.
The traditional procedure consists of the following steps:

-   identify an FRF of \\(G\_m\\)
-   decouple the plant to obtain an FRF of \\(G\\)
-   design \\(K\\) using manual loop-shaping, consisting of PID with notches
-   tune a feedforward controller, e.g. \\(f = m s^2 r\\)


## Precision motion control developments {#precision-motion-control-developments}


### Challenges {#challenges}

High performance mechatronic systems are becoming lighter and lighter.
Such lightweight systems exhibit predominant flexible dynamical behavior, as well as an increased susceptibility to disturbances.

This leads to several challenges for motion control design:

-   **Unmeasured performance variables** due to spatio-temporal deformations.
    In particular, the location where the performance is desired may not be directly measured.
-   **Many additional inputs and outputs** can be exploited to actively control the flexible dynamical behavior.
    Spatially distributed actuators can actively provide stiffness and damping to the mechanical deformations.
-   **Position dependent behavior** is almost unavoidable.
    For instance in gantry stage designs, mass distribution change due to motion, leading to additional position-dependent behavior.
    A key challenge lies in handling the position dependence of future systems
-   A **system-of-systems perspective** on motion control design provides a strong potential for performance enhancement of the overall system.
    In particular, typical manufacturing machines and scientific instruments involves multiple controlled subsystems where the two subsystems have to move relative to each other.
    Performance limitations in each subsystem will negatively impact the overall performance.
    A joint design enables that individual subsystems will be able to compensate each other's limitations.
    A main challenge lies in an increase of the complexity of the control problem.
-   **Thermal dynamics**, in addition to mechanical deformations are expected to become substantially more important due to increasing performance specifications.
-   **Vibrations**, such as flow induced vibrations of cooling liquids and floor vibrations, have to be attenuated.


### Generalized plant approach {#generalized-plant-approach}

A generalized plant framework allows for a systematic way to address the future challenges in advanced motion control.

The generalized plant is depicted in [Figure 3](#figure--fig:oomen18-generalized-plant):

-   \\(z\\) are the performance variables
-   \\(y\\) and \\(u\\) are the measured variables and measured variables, respectively
-   \\(w\\) contains the exogenous inputs, typically including both reference signals and disturbances.

<a id="figure--fig:oomen18-generalized-plant"></a>

{{< figure src="/ox-hugo/oomen18_generalized_plant.png" caption="<span class=\"figure-number\">Figure 3: </span>Generalized plant setup" >}}


## Feedback and Identification for Control {#feedback-and-identification-for-control}

Feedback control is essential to deal with uncertainty in the system dynamics \\(G\\) and disturbances \\(v\\).
Indeed, the main goal of feedback si to render the system insensitive to such uncertainties.


### Norm-based control {#norm-based-control}

A model-based design is foreseen to be able to systematically address the above mentioned challenges.

To specify the control goal, the criterion:

\begin{equation}
J(G, K) = \\| \mathcal{F}\_l(P(G), K) \\|
\end{equation}

is posed, where the goal is to compute:

\begin{equation}
K\_{\text{opt}} = \text{arg} \text{min}\_{K} J(G\_0, K)
\end{equation}

Where \\(\\| \cdot \\|\\) denotes a suitable norm, e.g. \\(\mathcal{H}\_2\\) or \\(\mathcal{H}\_\infty\\), and \\(\mathcal{F}\_l\\) denotes a lower linear fractional transformation.

\\(G\_0\\) denotes the true system, which is generally unknown and represented by a model \\(\hat{G}\\).


### Nominal modeling for control {#nominal-modeling-for-control}

To arrive at a mathematically tractable optimization problem, knowledge of the true system is represented through a model \\(\hat{G}\\).
The central question is how to obtain such a model that is suitable for controller design.
[System Identification]({{< relref "system_identification.md" >}}) as opposed to first principles modeling, is an inexpensive, fast and accurate approach to obtain such a model.
Indeed, the machine is often already built, enabling direct experimentation.

The model \\(\hat{G}\\) that results from system identification is an approximation of the true system \\(G\_0\\) for several reasons:

-   motion systems often contains an infinite number of modes \\(n\_s\\), while a model of limited complexity may be desirable from a control perspective
-   parasitic non-linearities are present, including nonlinear damping
-   identification experiments are based on finite time disturbed observations, leading to uncertainties on estimated parameters


### Toward robust motion control {#toward-robust-motion-control}

Doing a model based control design using an identified model may not work well due to a lack of robustness.
Indeed, if \\(K(\hat{G})\\) is designed solely based on \\(\hat{G}\\), there is no reason to assume that it achieves a suitable level of performance on \\(G\_0\\).
This motivates a robust control design, where the **model quality is explicitly addressed during controller synthesis**.


## Feedforward and learning {#feedforward-and-learning}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Oomen, Tom. 2018. “Advanced Motion Control for Precision Mechatronics: Control, Identification, and Learning of Complex Systems.” <i>IEEJ Journal of Industry Applications</i> 7 (2): 127–40. doi:<a href="https://doi.org/10.1541/ieejjia.7.127">10.1541/ieejjia.7.127</a>.</div>
</div>
