+++
title = "Vibrations and dynamic isotropy in hexapods-analytical studies"
author = ["Thomas Dehaeze"]
draft = false
ref_author = "Afzali-Far, B."
ref_year = 2016
+++

Tags
: [Stewart Platforms]({{<relref "stewart_platforms.md#" >}}), [Isotropy of Parallel Manipulator]({{<relref "isotropy_of_parallel_manipulator.md#" >}})

Reference
: ([Afzali-Far 2016](#org28bc5f9))

Author(s)
: Afzali-Far, B.

Year
: 2016


## Abstract {#abstract}

> The present work was initiated based on an industrial demand for designing a **high-bandwidth** hexapod of an advanced large optical telescope.
> In this dissertation, we have generalized this industrial problem to fully-parametric models of the hexapod vibrations as well as analytical studies on dynamic isotropy in parallel robots, which can be directly used in any hexapod applications.
>
> This work firstly establishes a comprehensive and fully parametric model for the vibrations in hexapods at symmetric configurations.
> We have developed three models:
>
> -   Cartesian-space formulation
> -   joint-space formulation
> -   refined model taking into account the inertia of the struts
>
> Kinematics of the hexapod are derived parametrically based on the Jacobian.
> Inertia, stiffness and damping matrices are also parametrically formulated.
> The eigenvectors and eigenfrequencies are then established in both the cartesian and joint spaces.
> By introducing the inertia of the struts, despite the apparent symmetric geometry, the equivalent inertia matrix in the cartesian space turns out to be non-diagonal matrix.
> In addition, the decoupled vibrations are analytically investigated where it is shown that the consideration of the strut inertia may lead to significant changes of the decoupling conditions.
>
> The problem of dynamic isotropy, as an optimal design solution for hexapods, is also addressed in this dissertation.
> Dynamic isotropy is a condition in which all eigenfrequencies of a robot are equal.
> This is a powerful tool in order to obtain dynamically optimized architectures for parallel robots.
> We analytically present the conditions of dynamic isotropy in hexapods with and without the consideration of the strut inertia.


## Introduction {#introduction}

The design variables of a hexapod (i.e. geometry, stiffness, damping and inertia properties) can be optimized based upon the requirements on the modal behavior (i.e. eigenfrequencies and eigenvectors of the system).
To do so, the following is performed parametrically:

-   parametric model
-   kinematics
-   linearized equations of motion
-   modal analysis

The linearized equations of motion are identified by stiffness, damping and inertia matrices.
These matrices can be expressed in terms of the **cartesian-space** or the **joint-space** coordinates.
In the cartesian space, the stiffness matrix is a function of the flexibility of the struts as well as the geometrical variables.
However, in the joint space, the stiffness matrix is not a function of geometrical variables.
The inertia matrix is a function of inertia properties as well as the geometrical variables.

Dynamic isotropy is an effective tool to avoid scattered eigenfrequencies in a system.
In a dynamic isotropy condition, all the eigenfrequencies of a system are equal.
Is is practically almost impossible to obtain dynamic isotropy based on the standard hexapod architecture.

> Hence, due to the fact that the control bandwidth of a hexapod is mechanically restricted by its natural frequencies, the optimization of the natural frequencies is of great importance.


## Parametric Modeling of Vibrations {#parametric-modeling-of-vibrations}


## Analytical Studies on Dynamics Isotropy {#analytical-studies-on-dynamics-isotropy}

<div class="definition">
  <div></div>

(complete) Dynamic isotropy is defined by:

\begin{equation}
M^{-1} K = \sigma I
\end{equation}

where \\(\sigma I\\) is a scaled identity matrix.
This implies that the eigenfrequencies of the matrix \\(M^{-1} K\\) are all equal:

\begin{equation}
\omega\_1 = \dots = \omega\_6 = \sqrt{\sigma}
\end{equation}

</div>

Dynamic isotropy for the Stewart platform leads to a series of restrictive conditions and a unique eigenfrequency:

\begin{equation}
\omega\_i = \sqrt{\frac{2k}{m\_p}}
\end{equation}

When considering inertia of the struts, conditions are becoming more complex.

<a id="org75888b1"></a>

{{< figure src="/ox-hugo/afzali-far16_isotropic_hexapod_example.png" caption="Figure 1: Architecture of the obtained dynamically isotropic hexapod" >}}

<div class="definition">
  <div></div>

Static isotropy can be defined by:

\begin{equation}
K\_C = J^T K\_J J = \sigma I
\end{equation}

where \\(\sigma I\\) is a scaled identity matrix.

</div>

The isotropic constrain of the standard hexapod imposes special inertia of the top platform which may not be wanted in practice (\\(I\_{zz} = 4 I\_{yy} = 4 I\_{xx}\\)).

A class of generalized Gough-Stewart platforms are proposed to eliminate the above constrains.
Figure [2](#org09a0134) shows a schematic of proposed generalized hexapod.

<a id="org09a0134"></a>

{{< figure src="/ox-hugo/afzali-far16_proposed_generalized_hexapod.png" caption="Figure 2: Parametrization of the proposed generalized hexapod" >}}


## Conclusions {#conclusions}

<div class="sum">
  <div></div>

The main findings of this dissertation are:

-   Comprehensive and fully parametric model of the hexapod for symmetric configurations are established both in the Cartesian and joint space.
-   Inertia of the struts are taken into account to refine the model.
-   A novel approach in order to obtain dynamically isotropic hexapods is proposed.
-   A novel architecture of hexapod is introduced (Figure [2](#org09a0134)) which is dynamically isotropic for a wide range of inertia properties.

</div>


## Bibliography {#bibliography}

<a id="org28bc5f9"></a>Afzali-Far, Behrouz. 2016. “Vibrations and Dynamic Isotropy in Hexapods-Analytical Studies.” Lund University.
