+++
title = "Signal to Noise Ratio"
author = ["Dehaeze Thomas"]
draft = false
+++

Tags
: [Electronics]({{< relref "electronics.md" >}}), [Dynamic Error Budgeting]({{< relref "dynamic_error_budgeting.md" >}})


## SNR to Noise PSD {#snr-to-noise-psd}

From (<a href="#citeproc_bib_item_2">Jabben 2007</a>) (Section 3.3.2):

> Electronic equipment does most often not come with detailed electric schemes, in which case the PSD should be determined from measurements.
> In the design phase however, one has to rely on information provided by specification sheets from the manufacturer.
> The noise performance of components like sensors, amplifiers, converters, etc., is often specified in terms of a **Signal to Noise Ratio** (SNR).
> The SNR gives the **ratio of the RMS value of a sine that covers the full range** of the channel through which the signal is propagating **over the RMS value of the electrical noise**.
>
> Usually, the SNR is specified up to a certain cut-off frequency.
> If no information on the colouring of the noise is available, then the corresponding **PSD can be assumed to be white up to the cut-off frequency** \\(f\_c\\):
> \\[ S\_{snr} = \frac{x\_{fr}^2}{8 f\_c C\_{snr}^2} \\]
> with \\(x\_{fr}\\) the full range of \\(x\\), and \\(C\_{snr}\\) the SNR.

<div class="exampl">

Let's take an example.

-   \\(x\_{fr} = 170 V\\)
-   \\(C\_{snr} = 85 dB\\)
-   \\(f\_c = 200 Hz\\)

The Power Spectral Density of the output voltage is:
\\[ S\_{snr} = \frac{170^2}{8 \cdot 200 \cdot {10^{\frac{2 \cdot 85}{20}}}} = 5.7 \cdot 10^{-8}\ V^2/Hz \\]

And the RMS of that noise up to \\(f\_c\\) is:
\\[ S\_{rms} = \sqrt{S\_{snr} \cdot f\_c} \approx 3.4\ mV \\]

</div>


## Convert SNR to Noise RMS value {#convert-snr-to-noise-rms-value}

The RMS value of the noise can be computed from:
\\[ N\_\text{rms} = 10^{-\frac{S\_{snr}}{20}} S\_\text{rms} \\]
where \\(S\_{snr}\\) is the SNR in dB and \\(S\_\text{rms}\\) is the RMS value of a sinus taking the full range.

If the full range is \\(\Delta V\\), then:
\\[ S\_\text{rms} = \frac{\Delta V/2}{\sqrt{2}} \\]

<div class="exampl">

As an example, let's take a voltage amplifier with a full range of \\(\Delta V = 20V\\) and a SNR of 85dB.
The RMS value of the noise is then:
\\[ n\_\text{rms} = 10^{-\frac{S\_{nrs}}{20}} s\_\text{rms} \\]

\\[ n\_\text{rms} = 10^{-\frac{85}{20}} \frac{10}{\sqrt{2}} \approx 0.4 mV\_\text{rms} \\]

</div>


## Convert wanted Noise RMS value to required SNR {#convert-wanted-noise-rms-value-to-required-snr}

If the wanted full range and RMS value of the noise are defined, the required SNR can be computed from:
\\[ S\_{snr} = 20 \log \frac{\text{Signal, rms}}{\text{Noise, rms}} \\]

<div class="exampl">

Let's say the wanted noise is \\(1 mV, \text{rms}\\) for a full range of \\(20 V\\), the corresponding SNR is:

\\[ S\_{snr} = 20 \log \frac{\frac{20/2}{\sqrt{2}}}{10^{-3}} \approx 77dB \\]

</div>


## Noise Density to RMS noise {#noise-density-to-rms-noise}

From (<a href="#citeproc_bib_item_1">Fleming 2010</a>):
\\[ \text{RMS noise} = \sqrt{2 \times \text{bandwidth}} \times \text{noise density} \\]

If the noise is normally distributed, the RMS value is also the standard deviation \\(\sigma\\).
The peak to peak amplitude is then approximately \\(6 \sigma\\).

<div class="exampl">

-   noise density = \\(20 pm/\sqrt{Hz}\\)
-   bandwidth = 100Hz

\\[ \sigma = \sqrt{2 \times 100} \times 20 = 0.28nm RMS \\]
The peak-to-peak noise will be approximately \\(6 \sigma = 1.7 nm\\)

</div>


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Fleming, A.J. 2010. “Nanopositioning System with Force Feedback for High-Performance Tracking and Vibration Control.” <i>IEEE/ASME Transactions on Mechatronics</i> 15 (3): 433–47. doi:<a href="https://doi.org/10.1109/tmech.2009.2028422">10.1109/tmech.2009.2028422</a>.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_2"></a>Jabben, Leon. 2007. “Mechatronic Design of a Magnetically Suspended Rotating Platform.” Delft University.</div>
</div>
